/**
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
import { IModel, FoundationModel, FoundationModelIdentifier } from 'aws-cdk-lib/aws-bedrock';
import { Grant, IGrantable } from 'aws-cdk-lib/aws-iam';
import { IConstruct } from 'constructs';
/**
 * Represents an Amazon Bedrock abstraction on which you can
 * run the `Invoke` API. This can be a Foundational Model,
 * a Custom Model, or an Inference Profile.
 */
export interface IInvokable {
    /**
     * The ARN of the Bedrock invokable abstraction.
     */
    readonly invokableArn: string;
    /**
     * Gives the appropriate policies to invoke and use the invokable abstraction.
     */
    grantInvoke(grantee: IGrantable): Grant;
}
export interface BedrockFoundationModelProps {
    /**
     * Bedrock Agents can use this model.
     *
     * @default - false
     */
    readonly supportsAgents?: boolean;
    /**
     * Bedrock Knowledge Base can use this model.
     *
     * @default - false
     */
    readonly supportsKnowledgeBase?: boolean;
    /**
     * Can be used with a Cross-Region Inference Profile
     * @default - false
     */
    readonly supportsCrossRegion?: boolean;
    /**
     * Embedding models have different vector dimensions.
     * Only applicable for embedding models.
     */
    readonly vectorDimensions?: number;
}
/**
 * Bedrock models.
 *
 * If you need to use a model name that doesn't exist as a static member, you
 * can instantiate a `BedrockFoundationModel` object, e.g: `new BedrockFoundationModel('my-model')`.
 */
export declare class BedrockFoundationModel implements IInvokable {
    /****************************************************************************
     *                            AMAZON
     ***************************************************************************/
    static readonly AMAZON_TITAN_TEXT_EXPRESS_V1: BedrockFoundationModel;
    static readonly AMAZON_TITAN_PREMIER_V1_0: BedrockFoundationModel;
    static readonly AMAZON_NOVA_MICRO_V1: BedrockFoundationModel;
    static readonly AMAZON_NOVA_LITE_V1: BedrockFoundationModel;
    static readonly AMAZON_NOVA_PRO_V1: BedrockFoundationModel;
    static readonly TITAN_EMBED_TEXT_V1: BedrockFoundationModel;
    static readonly TITAN_EMBED_TEXT_V2_1024: BedrockFoundationModel;
    static readonly TITAN_EMBED_TEXT_V2_512: BedrockFoundationModel;
    static readonly TITAN_EMBED_TEXT_V2_256: BedrockFoundationModel;
    /****************************************************************************
     *                            ANTHROPIC
     ***************************************************************************/
    static readonly ANTHROPIC_CLAUDE_3_5_SONNET_V2_0: BedrockFoundationModel;
    static readonly ANTHROPIC_CLAUDE_3_5_SONNET_V1_0: BedrockFoundationModel;
    static readonly ANTHROPIC_CLAUDE_3_5_HAIKU_V1_0: BedrockFoundationModel;
    static readonly ANTHROPIC_CLAUDE_OPUS_V1_0: BedrockFoundationModel;
    static readonly ANTHROPIC_CLAUDE_SONNET_V1_0: BedrockFoundationModel;
    static readonly ANTHROPIC_CLAUDE_HAIKU_V1_0: BedrockFoundationModel;
    static readonly ANTHROPIC_CLAUDE_V2_1: BedrockFoundationModel;
    static readonly ANTHROPIC_CLAUDE_V2: BedrockFoundationModel;
    static readonly ANTHROPIC_CLAUDE_INSTANT_V1_2: BedrockFoundationModel;
    /****************************************************************************
     *                            COHERE
     ***************************************************************************/
    static readonly COHERE_EMBED_ENGLISH_V3: BedrockFoundationModel;
    static readonly COHERE_EMBED_MULTILINGUAL_V3: BedrockFoundationModel;
    /****************************************************************************
     *                            META
     ***************************************************************************/
    static readonly META_LLAMA_3_2_11B_INSTRUCT_V1: BedrockFoundationModel;
    static readonly META_LLAMA_3_2_3B_INSTRUCT_V1: BedrockFoundationModel;
    static readonly META_LLAMA_3_2_1B_INSTRUCT_V1: BedrockFoundationModel;
    static fromCdkFoundationModelId(modelId: FoundationModelIdentifier, props?: BedrockFoundationModelProps): BedrockFoundationModel;
    static fromCdkFoundationModel(modelId: FoundationModel, props?: BedrockFoundationModelProps): BedrockFoundationModel;
    /****************************************************************************
     *                            Constructor
     ***************************************************************************/
    readonly modelId: string;
    readonly modelArn: string;
    readonly invokableArn: string;
    readonly supportsAgents: boolean;
    readonly supportsCrossRegion: boolean;
    readonly vectorDimensions?: number;
    readonly supportsKnowledgeBase: boolean;
    constructor(value: string, props?: BedrockFoundationModelProps);
    toString(): string;
    /**
     * Returns the ARN of the foundation model in the following format:
     * `arn:${Partition}:bedrock:${Region}::foundation-model/${ResourceId}`
     */
    asArn(construct: IConstruct): string;
    asIModel(construct: IConstruct): IModel;
    /**
     * Gives the appropriate policies to invoke and use the Foundation Model in the stack region.
     */
    grantInvoke(grantee: IGrantable): Grant;
    /**
     * Gives the appropriate policies to invoke and use the Foundation Model in all regions.
     */
    grantInvokeAllRegions(grantee: IGrantable): Grant;
}
